@@ -41,10 +41,17 @@ from .utils.setup import validate_environment, check_ffmpeg
 
 class ReaderApp:
     """Main application class."""
-    
+
     def __init__(self, init_tts=False):
         """Initialize the reader application."""
-        self.config_manager = ConfigManager()
+        # Early FFmpeg warning (non-blocking)
+        if not shutil.which("ffmpeg"):
+            print("⚠️  FFmpeg not detected (required for audio conversion)")
+            print("💡 Install: brew install ffmpeg (macOS) | winget install ffmpeg (Windows) | sudo apt install ffmpeg (Linux)\n")
+
+        # Use system-standard config location (works in CLI, GUI, and app bundles)
+        config_path = Path.home() / ".config/audiobook-reader/settings.yaml"
+        self.config_manager = ConfigManager(config_path)
 
         # Use system temp for working files (session-specific workspace)
         self.temp_workspace = Path(tempfile.mkdtemp(prefix="audiobook-reader-"))
@@ -210,7 +217,8 @@ class ReaderApp:
         debug: bool = False,
         progress_style: str = "timeseries",
         character_config: Optional[Path] = None,
-        output_dir: Optional[str] = None
+        output_dir: Optional[str] = None,
+        clean_text: bool = True
     ) -> Path:
         """Convert a single file to audiobook."""
         # Get parser
@@ -221,7 +229,29 @@ class ReaderApp:
         # Parse content
         click.echo(f"Parsing {file_path.name}...")
         parsed_content = parser.parse(file_path)
-        
+
+        # Clean text for better TTS processing
+        if clean_text:
+            from reader.text_processing.text_cleaner import TextCleaner
+            cleaner = TextCleaner()
+
+            # Extract only narrative content (removes front/back matter)
+            if parsed_content.chapters:
+                original_count = len(parsed_content.chapters)
+                # Rebuild content from narrative chapters only
+                parsed_content.content = cleaner.extract_narrative_content(parsed_content.chapters)
+                # Filter chapter list
+                parsed_content.chapters = [
+                    ch for ch in parsed_content.chapters
+                    if not cleaner.should_skip_chapter(ch.get('title', ''))
+                ]
+                skipped = original_count - len(parsed_content.chapters)
+                if skipped > 0:
+                    click.echo(f"Skipped {skipped} non-narrative chapter(s) (TOC, bibliography, etc.)")
+
+            # Apply text cleaning to final content
+            parsed_content.content = cleaner.clean(parsed_content.content)
+
         # Get configuration
         tts_config = self.config_manager.get_tts_config()
         audio_config = self.config_manager.get_audio_config()
@@ -446,7 +476,8 @@ def cli():
 @click.option('--debug', is_flag=True, default=False, help='Show detailed debug output including Neural Engine status')
 @click.option('--progress-style', type=click.Choice(['simple', 'tqdm', 'rich', 'timeseries']), default='timeseries', help='Progress display: simple (text), tqdm (bars), rich (fancy), timeseries (charts)')
 @click.option('--output-dir', help='Output directory: "downloads" (~/Downloads), "same" (next to source), or explicit path')
-def convert(voice, speed, format, file, characters, character_config, chapters, dialogue, processing_level, batch_mode, checkpoint_interval, turbo_mode, debug, progress_style, output_dir):
+@click.option('--no-clean-text', is_flag=True, help='Disable text cleanup (keep broken words, bibliography, etc.)')
+def convert(voice, speed, format, file, characters, character_config, chapters, dialogue, processing_level, batch_mode, checkpoint_interval, turbo_mode, debug, progress_style, output_dir, no_clean_text):
     """Convert text file to audiobook.
 
     All options are temporary overrides and won't be saved to config.
@@ -482,7 +513,8 @@ def convert(voice, speed, format, file, characters, character_config, chapters,
                 batch_mode=batch_mode, checkpoint_interval=checkpoint_interval,
                 turbo_mode=turbo_mode, debug=debug, progress_style=progress_style,
                 character_config=Path(character_config) if character_config else None,
-                output_dir=output_dir
+                output_dir=output_dir,
+                clean_text=not no_clean_text
             )
             click.echo(f"✓ Conversion complete: {output_path}")
         except Exception as e:
@@ -949,7 +981,7 @@ def info():
     click.echo("  docs/EXAMPLES.md - Real-world examples and workflows")
 
     click.echo("\n🎯 Features:")
-    click.echo("  ✅ Neural TTS (Kokoro) with 48+ voices")
+    click.echo("  ✅ Neural TTS (Kokoro) with 54 voices across 9 languages")
     click.echo("  ✅ Apple Neural Engine acceleration (M1/M2/M3)")
     click.echo("  ✅ Professional audio formats (MP3, M4A, M4B)")
     click.echo("  ✅ Emotion detection and dialogue analysis")
